pub struct RequestData<U> {
pub app_id: Option<String>,
pub seat_and_serial: Option<(WlSeat, u32)>,
pub surface: Option<WlSurface>,
pub udata: U,
}Expand description
Minimal implementation of [RequestDataExt].
Use a custom type implementing [RequestDataExt] to store more data with a token request
e.g. to identify which request produced which token.
Fields
app_id: Option<String>App_id of the application requesting the token, if applicable
seat_and_serial: Option<(WlSeat, u32)>Seat and serial of the window requesting the token, if applicable.
Warning: Many compositors will issue invalid tokens for requests without recent serials. There is no way to detect this from the client-side.
surface: Option<WlSurface>Surface of the window requesting the token, if applicable.
Warning: Many compositors will issue invalid tokens for requests from unfocused surfaces. There is no way to detect this from the client-side.
udata: UTrait Implementations
Sourceimpl<U: Clone> Clone for RequestData<U>
impl<U: Clone> Clone for RequestData<U>
Sourcefn clone(&self) -> RequestData<U>
fn clone(&self) -> RequestData<U>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<U: Debug> Debug for RequestData<U>
impl<U: Debug> Debug for RequestData<U>
Sourceimpl<D, U> Dispatch2<XdgActivationTokenV1, D> for RequestData<U>where
D: ActivationHandler<RequestUdata = U>,
impl<D, U> Dispatch2<XdgActivationTokenV1, D> for RequestData<U>where
D: ActivationHandler<RequestUdata = U>,